.. _pyreference:

******
Python
******

In the following, we describe the additional python functionality
that is not already part of Dune or dune-fem, and is exclusively available for Dune-MMesh.

.. toctree::
  :maxdepth: 1

  pyreference/grid
  pyreference/trace
  pyreference/utility
  pyreference/solve
